@@ -47,6 +47,9 @@ class LSsearchEntry {
   
   // Cache
   private $cache=array();
+
+  // Other values
+  private $other_values=array();
   
   /**
    * Constructor
@@ -81,11 +84,26 @@ class LSsearchEntry {
     if (in_array($key,array_keys($this -> attrs))) {
       return $this -> attrs[$key];
     }
+    elseif (array_key_exists($key,$this->other_values)) {
+      return $this->other_values[$key];
+    }
     elseif ($key=='subDn' || $key=='subDnName') {
       return $this -> subDn;
     }
   }
 
+  /**
+   * Add value in array $this -> other_values
+   *
+   * @param[in] $name string The value name
+   * @param[in] $value mixed The value
+   *
+   * @retval void
+   **/
+  function registerOtherValue($name,$value) {
+    $this -> other_values[$name]=$value;
+  }
+
   /**
    * Get formated text value of entry
    * 
@@ -185,6 +203,20 @@ class LSsearchEntry {
           if (!empty($ret)) break;
         }
       }
+      if (!empty($ret) && isset($this->LSsearch->extraDisplayedColumns[$key]['formaterLSformat'])) {
+        $this -> registerOtherValue('val',$ret);
+        $ret=$this -> getFData($this->LSsearch->extraDisplayedColumns[$key]['formaterLSformat']);
+      }
+      if (!empty($ret) && isset($this->LSsearch->extraDisplayedColumns[$key]['formaterFunction'])) {
+        if (is_callable($this->LSsearch->extraDisplayedColumns[$key]['formaterFunction'])) {
+          $ret=call_user_func($this->LSsearch->extraDisplayedColumns[$key]['formaterFunction'],$ret);
+        }
+        else {
+          $func=$this->LSsearch->extraDisplayedColumns[$key]['formaterFunction'];
+          if(is_array($func)) $func=print_r($func,1);
+          LSerror::addErrorCode('LSsearchEntry_01',array('func' => $func, 'column' => $key));
+        }
+      }
       $this -> cache[$key] = $ret;
       return $ret;
     }
@@ -211,4 +243,9 @@ class LSsearchEntry {
 
 }
 
-?>
+/**
+ * Error Codes
+ **/
+LSerror :: defineError('LSsearchEntry_01',
+_("LSsearchEntry : Invalid formaterFunction %{func} for extraDisplayedColumns %{column}.")
+);
