@@ -23,14 +23,22 @@
 
 error_reporting(E_ERROR);
 
-require_once('../core.php');
-require_once('../conf/config.inc.php');
+// Change directory
+$curdir=getcwd();
+chdir(dirname(__FILE__).'/../');
+
+require_once('core.php');
+require_once('conf/config.inc.php');
 
 $withoutselectlist=False;
 $copyoriginalvalue=False;
 $additionalfileformat=False;
+$lang=False;
+$encoding=False;
 $translations=array();
 if ($argc > 1) {
+  // Change dir again to manage file input
+  chdir($curdir);
   for ($i=1;$i<$argc;$i++) {
     if (is_file($argv[$i])) {
       @include($argv[$i]);
@@ -47,25 +55,48 @@ if ($argc > 1) {
     elseif($argv[$i]=='--additional-file-format') {
       $additionalfileformat=True;
     }
+    elseif($argv[$i]=='--lang') {
+      $i++;
+      $parse_lang=explode('.',$argv[$i]);
+      if (count($parse_lang)==2) {
+        $lang=$parse_lang[0];
+        $encoding=$parse_lang[1];
+      }
+      else {
+        die("Invalid --lang parameter. Must be compose in format : [lang].[encoding]\n");
+      }
+    }
     elseif($argv[$i]=='-h') {
       echo "Usage : ".$argv[0]." [file1] [file2] [-h] [options]\n";
       echo "  --without-select-list    Don't add possibles values of select list\n";
       echo "  --copy-original-value    Copy original value as translated value when no translated value exists\n";
       echo "  --additional-file-format Additional file format output\n";
+      echo "  --lang                   Load this specify lang (format : [lang].[encoding])\n";
       exit(0);
     }
   }
+  chdir(dirname(__FILE__).'/../');
 }
 
 $data=array();
 
 function add($msg) {
-  if ($msg!='') {
+  if ($msg!='' && _($msg) == "$msg") {
     global $data, $translations;
     $data[$msg]=$translations[$msg];
   }
 }
 
+// Initialize session
+LSsession :: initialize($lang,$encoding);
+
+// Load lang string if lang was specify
+if ($lang && $encoding) {
+  foreach($GLOBALS['LSlang'] as $msg => $trans) {
+    $translations[$msg]=$trans;
+  }
+}
+
 // LDAP Servers
 foreach($GLOBALS['LSconfig']['ldap_servers'] as $conf) {
   add($conf['name']);
@@ -85,7 +116,7 @@ foreach($GLOBALS['LSconfig']['ldap_servers'] as $conf) {
 
 
 // LSobject
-if (loadDir('../'.LS_OBJECTS_DIR) && loadDir('../'.LS_LOCAL_DIR.LS_OBJECTS_DIR)) {
+if (loadDir(LS_OBJECTS_DIR) && loadDir(LS_LOCAL_DIR.LS_OBJECTS_DIR)) {
   foreach($GLOBALS['LSobjects'] as $name => $conf) {
     add($conf['label']);
     
@@ -218,8 +249,63 @@ function find_and_parse_template_file($dir) {
   }
 }
 
-find_and_parse_template_file('../'.LS_TEMPLATES_DIR);
-find_and_parse_template_file('../'.LS_LOCAL_DIR.LS_TEMPLATES_DIR);
+find_and_parse_template_file(LS_TEMPLATES_DIR);
+find_and_parse_template_file(LS_LOCAL_DIR.LS_TEMPLATES_DIR);
+
+/*
+ * Manage addons files
+ */
+
+function parse_addon_file($file) {
+  foreach(file($file) as $line) {
+    $offset=0;
+    while ($pos = strpos($line,'__(',$offset)) {
+      $quote='';
+      $res='';
+      for ($i=$pos+3;$i<strlen($line);$i++) {
+        if (empty($quote)) {
+          if ($line[$i]=='\\') {
+            $i++;
+          }
+          elseif ($line[$i]=='"' || $line[$i]=="'") {
+            $quote=$line[$i];
+          }
+        }
+        elseif (!empty($quote)) {
+          if ($line[$i]=='\\') {
+            $res.=$line[$i];
+            $i++;
+            $res.=$line[$i];
+          }
+          elseif ($line[$i]==$quote) {
+            $offset=$i;
+            break;
+          }
+          else {
+            $res.=$line[$i];
+          }
+        }
+      }
+      if (!empty($res)) add($res);
+    }
+  }
+}
+
+function find_and_parse_addon_file($dir) {
+  if (is_dir($dir)) {
+    if ($dh = opendir($dir)) {
+      while (($file = readdir($dh)) !== false) {
+        if (preg_match('/^LSaddons\.(.+)\.php$/',$file)) {
+          parse_addon_file($dir.'/'.$file);
+        }
+      }
+      closedir($dh);
+    }
+  }
+}
+
+find_and_parse_addon_file(LS_ADDONS_DIR);
+find_and_parse_addon_file(LS_LOCAL_DIR.LS_ADDONS_DIR);
 
 
 ksort($data);
